<template>
    <div class="app-container">
       <el-form :model="queryParams" ref="queryRef" :inline="true">
          <el-form-item label="权限名称" prop="name">
             <el-input
                v-model="queryParams.name"
                placeholder="请输入权限名称"
                clearable
                style="width: 200px"
                @keyup.enter="handleQuery"
             />
          </el-form-item>
          <el-form-item>
             <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
             <el-button icon="Refresh" @click="resetQuery">重置</el-button>
          </el-form-item>
       </el-form>
 
       <el-row :gutter="10" class="mb8">
          <el-col :span="1.5">
             <el-button
                type="primary"
                plain
                icon="Plus"
                @click="handleAdd"
             >新增</el-button>
          </el-col>
       </el-row>
       <!--表格及分页-->
       <el-table v-loading="loading" :data="tableData">
          <el-table-column
            v-for="(item, key, index) of tableHeader"
            :prop="key.toString()"
            :label="item"
            :key="index"
            align="center"
          ></el-table-column>
          <el-table-column label="操作" width="180" align="center" class-name="small-padding fixed-width">
             <template #default="scope">
                <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)">修改</el-button>
                <el-button link type="primary" icon="Delete" @click="handleDelete(scope.row)">删除</el-button>
             </template>
          </el-table-column>
        </el-table>
        <pagination
          :total="pageParam.total"
          v-model:page="pageParam.page"
          v-model:limit="pageParam.limit"
          :page-sizes="[10,20,30]"
          @pagination="getList"
        />
       <!-- 添加或修改对话框 -->
       <el-dialog :title="title" v-model="open" append-to-body center>
          <el-form class="form-box" ref="permissionRef" :model="form" :rules="rules" label-width='auto'>
                   <el-form-item label="权限值" prop="sn">
                      <el-input v-model="form.sn" placeholder="请输入权限值"/>
                   </el-form-item>
                   <el-form-item label="权限名称" prop="name">
                      <el-input v-model="form.name" placeholder="请输入权限名称" />
                   </el-form-item>
                    <el-form-item label="菜单" prop="menuId">
                      <el-tree-select
                         v-model="form.menuId"
                         :data="menuOptions"
                         :props="{ value: 'id', label: 'name', children: 'children' }"
                         value-key="id"
                         placeholder="选择菜单"
                         check-strictly
                      />
                   </el-form-item>
                   <el-form-item label="类型" placeholder="请选择权限类型" prop="type">
                        <el-select v-model="form.type">
                            <el-option 
                            v-for="(item,index) in typeList"
                            :label="item.name"
                            :value="item.value"
                            :key="index"
                            ></el-option>
                        </el-select>
                   </el-form-item>
          </el-form>
          <template #footer>
             <div class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
             </div>
          </template>
       </el-dialog>
    </div>
 </template>
 
 <script setup>
 import  permission from "@/api/system/permission";
 import  { DictType }  from "@/api/system/dict";
 import  menu from "@/api/system/menu";
 import setPostParams from "../../../utils/searchParams.js";
 const { proxy } = getCurrentInstance();
 
/**
 * 搜索相关
 */
 /** 搜索按钮操作 */
 function handleQuery() {
   getList({keywords:queryParams.value.name,page:1})
 }
 
 /** 重置按钮操作 */
 function resetQuery() {
   proxy.resetForm("queryRef");
   handleQuery();
 }

 /**
  *  Table表格权限数据列表相关
  */


const pageParam = ref({
    total:0,
    limit:0,
    page:0,
})
const tableData = ref([]);
let  tableHeader = ref({
    sn: '权限值',
    name: '权限名称',
    menuId:'菜单',
    type:'权限类型'
   })

 /** 获取列表 */
 async function getList(val) {
      loading.value = true;

     let postParam = setPostParams(val)
      await permission().search(postParam).then((res) =>{
        tableData.value = res.data.list
        pageParam.value.total = res.data.total
        pageParam.value.limit = res.data.limit
        pageParam.value.page = res.data.page
        console.log('pa',pageParam.value);
    })
    loading.value = false;
 }
 
 //获取菜单类型
 const typeList = ref()
 const getType = async() =>{
   await DictType().getEnum('EOperation').then((res) =>{
      typeList.value = res.data
      console.log('typeList.value ',typeList.value );
   })
 }
 
 /** 新增按钮操作 */
 async function handleAdd() {
   reset();
   open.value = true;
   title.value = "添加权限";
   await getMenuList()
 }
 
 /** 修改按钮操作 */
 async function handleUpdate(row) {
   reset();
   form.value = Object.assign({},row)
   await getMenuList()
   open.value = true;
   title.value = "修改权限";
 }

/** 删除按钮操作 */
function handleDelete(row) {
  proxy.$modal.confirm('是否确认删除名称为"' + row.name + '"的数据项?').then(function() {
    return permission().remove(row.id);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}
 

 /**
  *  新增/修改弹窗Form表单相关
  */
const open = ref(false);
const loading = ref(false);
const title = ref("");

const data = reactive({
form:{},
queryParams: {
    name: undefined,
},
rules: {
    sn: [{ required: true, message: "权限值不能为空", trigger: "blur" }],
    name: [{ required: true, message: "权限名称不能为空", trigger: "blur" }],
    menuId: [{ required: true, message: "所属菜单不能为空", trigger: "blur" }],
    type: [{ required: true, message: "类型不能为空", trigger: "blur" }]
},
});
const { queryParams, form, rules } = toRefs(data);

//获取菜单选项列表
const menuOptions = ref([])
const getMenuList = async() =>{
    await menu().getListTree().then((res) =>{
        menuOptions.value = res.data
    })
}
 /** 提交按钮 */
 function submitForm() {
   proxy.$refs["permissionRef"].validate(valid => {
     if (valid) {
        form.value.parentId = form.value.parentId == '' ? 0 : form.value.parentId
       if (form.value.id != undefined) {
         permission().modify(form.value).then(res => {
           proxy.$modal.msgSuccess("修改成功");
           open.value = false;
           getList();
         }).catch(() =>{
            open.value = false;
            proxy.$modal.msgError("修改失败");
         });
       } else {
         permission().create(form.value).then(res => {
           proxy.$modal.msgSuccess("新增成功");
           open.value = false;
           getList();
         }).catch(() =>{
            open.value = false;
            proxy.$modal.msgError("新增失败");
         });;
       }
     }
   });
 }

 /** 取消按钮 */
 function cancel() {
   open.value = false;
   reset();
 }
 
 /** 表单重置 */
 function reset() {
   form.value = {
        sn: undefined,
        menuId: '',
        name: undefined,
        type: undefined,
   };
   proxy.resetForm("permissionRef");
 }
 getType()
 getList();
 </script>
 